@@ -15,7 +15,7 @@ our @ISA = qw(DynaLoader);
 # SQL_DRIVER_VER is formatted as dd.dd.dddd
 # for version 5.x please switch to 5.00(_00) version numbering
 # keep $VERSION in Bundle/DBD/mysql.pm in sync
-our $VERSION = '4.034';
+our $VERSION = '4.036';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -898,37 +898,19 @@ DBD::mysql - MySQL driver for the Perl5 Database Interface (DBI)
 
     use DBI;
 
-    $dsn = "DBI:mysql:database=$database;host=$hostname;port=$port";
+    my $dsn = "DBI:mysql:database=$database;host=$hostname;port=$port";
+    my $dbh = DBI->connect($dsn, $user, $password);
 
-    $dbh = DBI->connect($dsn, $user, $password);
-
-
-    $drh = DBI->install_driver("mysql");
-    @databases = DBI->data_sources("mysql");
-       or
-    @databases = DBI->data_sources("mysql",
-      {"host" => $host, "port" => $port, "user" => $user, password => $pass});
-
-    $sth = $dbh->prepare("SELECT * FROM foo WHERE bla");
-       or
-    $sth = $dbh->prepare("LISTFIELDS $table");
-       or
-    $sth = $dbh->prepare("LISTINDEX $table $index");
-    $sth->execute;
-    $numRows = $sth->rows;
-    $numFields = $sth->{'NUM_OF_FIELDS'};
+    my $sth = $dbh->prepare(
+        'SELECT id, first_name, last_name FROM authors WHERE last_name = ?')
+        or die "prepare statement failed: $dbh->errstr()";
+    $sth->execute('Eggers') or die "execution failed: $dbh->errstr()";
+    print $sth->rows . " rows found.\n";
+    while (my $ref = $sth->fetchrow_hashref()) {
+        print "Found a row: id = $ref->{'id'}, fn = $ref->{'first_name'}\n";
+    }
     $sth->finish;
 
-    $rc = $drh->func('createdb', $database, $host, $user, $password, 'admin');
-    $rc = $drh->func('dropdb', $database, $host, $user, $password, 'admin');
-    $rc = $drh->func('shutdown', $host, $user, $password, 'admin');
-    $rc = $drh->func('reload', $host, $user, $password, 'admin');
-
-    $rc = $dbh->func('createdb', $database, 'admin');
-    $rc = $dbh->func('dropdb', $database, 'admin');
-    $rc = $dbh->func('shutdown', 'admin');
-    $rc = $dbh->func('reload', 'admin');
-
 
 =head1 EXAMPLE
 
@@ -1373,70 +1355,6 @@ method.  Instead, you should use the portable method
 =back
 
 
-=head2 Server Administration
-
-=over
-
-=item admin
-
-    $rc = $drh->func("createdb", $dbname, [host, user, password,], 'admin');
-    $rc = $drh->func("dropdb", $dbname, [host, user, password,], 'admin');
-    $rc = $drh->func("shutdown", [host, user, password,], 'admin');
-    $rc = $drh->func("reload", [host, user, password,], 'admin');
-
-      or
-
-    $rc = $dbh->func("createdb", $dbname, 'admin');
-    $rc = $dbh->func("dropdb", $dbname, 'admin');
-    $rc = $dbh->func("shutdown", 'admin');
-    $rc = $dbh->func("reload", 'admin');
-
-For server administration you need a server connection. For obtaining
-this connection you have two options: Either use a driver handle (drh)
-and supply the appropriate arguments (host, defaults localhost, user,
-defaults to '' and password, defaults to ''). A driver handle can be
-obtained with
-
-    $drh = DBI->install_driver('mysql');
-
-Otherwise reuse the existing connection of a database handle (dbh).
-
-There's only one function available for administrative purposes, comparable
-to the mysqladmin programs. The command being execute depends on the
-first argument:
-
-=over
-
-=item createdb
-
-Creates the database $dbname. Equivalent to "mysqladmin create $dbname".
-
-=item dropdb
-
-Drops the database $dbname. Equivalent to "mysqladmin drop $dbname".
-
-It should be noted that database deletion is
-I<not prompted for> in any way.  Nor is it undo-able from DBI.
-
-    Once you issue the dropDB() method, the database will be gone!
-
-These method should be used at your own risk.
-
-=item shutdown
-
-Silently shuts down the database engine. (Without prompting!)
-Equivalent to "mysqladmin shutdown".
-
-=item reload
-
-Reloads the servers configuration files and/or tables. This can be particularly
-important if you modify access privileges or create new users.
-
-=back
-
-=back
-
-
 =head1 DATABASE HANDLES
 
 The DBD::mysql driver supports the following attributes of database
@@ -1664,8 +1582,15 @@ or using an existing database handle:
 
   $dbh->{mysql_no_autocommit_cmd} = 1;
 
+=item ping
+
+This can be used to send a ping to the server.
+
+  $rc = $dbh->ping();
+
 =back
 
+
 =head1 STATEMENT HANDLES
 
 The statement handles of DBD::mysql support a number
@@ -1727,10 +1652,14 @@ have impact on the I<max_length> attribute.
 
 =item mysql_insertid
 
-MySQL has the ability to choose unique key values automatically. If this
-happened, the new ID will be stored in this attribute. An alternative
-way for accessing this attribute is via $dbh->{'mysql_insertid'}.
-(Note we are using the $dbh in this case!)
+If the statement you executed performs an INSERT, and there is an AUTO_INCREMENT
+column in the table you inserted in, this attribute holds the value stored into
+the AUTO_INCREMENT column, if that value is automatically generated, by
+storing NULL or 0 or was specified as an explicit value.
+
+Typically, you'd access the value via $sth->{mysql_insertid}. The value can
+also be accessed via $dbh->{mysql_insertid} but this can easily
+produce incorrect results in case one database handle is shared.
 
 =item mysql_is_blob
 
